function [] = point_display(sys,Uf)

H=sys.H;
DHp1 = 2*H+1;

switch sys.type
    case 'HBM'
        
        % Computation of the periodic solution over 1 period : time is a
        % dimensionless time vector.
        time = linspace(0,1,1000);
        Ut = calcperiodHBM(sys,Uf,[1 2 3 4],time);
        
    case 'QPHBM'
        % The quasi-periodic solution is reconstructed over the grid
        % time below from the Fourier coefficients computed.
        
        [Ztot,omega1,omega2,lambda]=sys.get_Ztot(Uf);
        Tmax=2*pi/omega1 + 2*pi/omega2;
        nb = 200;
        time=linspace(0,nb*Tmax,nb*400);
        nt=length(time);
        
        Zcompl = sys.real_to_compl(Ztot);
        
        VectExp=zeros(nt,H*(DHp1+1));
        for k=1:H
            VectExp(:,k) = exp(1i*omega2*k*time);
        end
        for l=1:H
            for k=-H:1:H
                VectExp(:,l*DHp1+k) = exp(1i*(l*omega1+k*omega2)*time);
            end
        end
        MAT = [ones(nt,1) , VectExp];
        Ut = real(MAT*Zcompl);
        
end

figure(11);
plot(time,Ut(:,1),'b',time,Ut(:,3),'r')
title(['Time evolution of q_1 and q_2 with ' num2str(H) ' harmonics'],'Fontsize',16)
xlabel('time (s)');legend(['q_1'],['q_2'],'Location','SouthEast');grid on;

figure(12)
plot3(Ut(:,1),Ut(:,2),Ut(:,3))
xlabel('q_1')
ylabel('p_1')
zlabel('q_2')

end
